\name{aircraft}
\alias{aircraft}
\alias{aircraft.x}
\alias{aircraft.y}
\docType{data}
\title{ Aircraft Data
}
\description{
   Aircraft Data, deals with 23 single-engine aircraft built 
over the years 1947-1979, from Office of Naval Research. 
The dependent variable is cost  (in units of \$100,000) 
and the explanatory variables are aspect ratio, lift-to-drag ratio, 
weight of plane (in pounds) and maximal thrust.

}
\usage{data(aircraft)}
\format{
  A data frame with 23 observations on the following 5 variables.
  \describe{
    \item{\code{X1}}{Aspect Ratio}
    \item{\code{X2}}{Lift-to-Drag Ratio}
    \item{\code{X3}}{Weight}
    \item{\code{X4}}{Thrust}
    \item{\code{Y}}{Cost}
  }
 For convenience, the data sets \code{aircraft.x}, a matrix with 
the four (independent) variables of the data frame, and \code{aircraft.y}, 
the numeric vector giving the fifth (dependent) variable, are provided as well. 
}
\source{
 P. J. Rousseeuw and A. M. Leroy (1987) 
 \emph{Robust Regression and Outlier Detection.} Wiley, page 154, table 22. 

}
\examples{
data(aircraft)
covMcd(aircraft.x)

summary(lm.aircraft <- lm(aircraft.y ~ aircraft.x))

}
\keyword{datasets}

\eof
\name{brain}
\alias{brain}
\docType{data}
\title{ Brain and Body Weights for 28 Species }
\description{
   Average brain and body weights for 28 species of land animals. 
If the log of the two variables, i.e. log(brain weight) and 
log(body weight) are taken, the classical Mahalanobis distance 
declares only observation 25 (Brachiosaurus) as an outlier, 
whereas the robust distances computed using for example MCD - 
covMcd() - declare four observations as outliers (25, 6, 14 and 16). 
These are three dinosaurs with relatively small brains and the 
human with relatively heavy brain.
}
\usage{data(brain)}
\format{
  A data frame with 28 observations on the following 2 variables.
  \describe{
    \item{\code{body}}{body weight in kg}
    \item{\code{brain}}{brain weight in g}
  }
}
\Note{
  This data set is also available in the package MASS under the name 'Animals', but the observations 25 (Brachiosaurus) and 26 (Rat) are swaped.
}
\source{
 P. J. Rousseeuw and A. M. Leroy (1987) 
 \emph{Robust Regression and Outlier Detection.} Wiley, p.57. 
 
}
\examples{
data(brain)
lbrain<-log(brain)
plot(mahalanobis(lbrain,mean(lbrain),var(lbrain)))

mcd<-covMcd(lbrain)
plot(mahalanobis(lbrain,mcd$center,mcd$cov))

}
\keyword{datasets}

\eof
\name{bushfire}
\alias{bushfire}
\docType{data}
\title{ Campbell Bushfire Data }
\description{

This data set was used by Campbell (1984) to locate bushfire scars. 
The dataset contains satelite measurements on five frequency bands, 
corresponding to each of 38 pixels.
}
\usage{data(bushfire)}
\format{
  A data frame with 38 observations on 5 variables.
%  \describe{}
}
%\Note{}
\source{
Maronna, R.A. and Yohai, V.J., The Behavoiur of the Stahel-Donoho
Robust Multivariate Estimator. \emph{Journal of the American Statistical
Assosiation}, \bold{90} (1995) 330--341.

}

%\seealso{}
\examples{
data(bushfire)
plot(bushfire)
covMcd(bushfire)
}
\keyword{datasets}

\eof
\name{coleman}
\alias{coleman}
\alias{coleman.x}
\alias{coleman.y}
\docType{data}
\title{ Coleman Data Set
 }
\description{
   Contains information on 20 Schools from the Mid-Atlantic and New England States, 
drawn from a population studied by Coleman et al. (1966). Mosteller and Tukey (1977) 
analyze this sample consisting of measurements on six different variables, one of 
which will be treated as a responce.
}
\usage{data(coleman)}
\format{
  A data frame with 20 observations on the following 6 variables.
  \describe{
    \item{\code{X1}}{staff salaries per pupil}
    \item{\code{X2}}{percent of white-collar fathers}
    \item{\code{X3}}{socioeconomic status composite deviation: means for family size, family intactness, father's education, mother's education, and home items}
    \item{\code{X4}}{mean teacher's verbal test score}
    \item{\code{X5}}{mean mother's educational level, one unit is equal to two school years}
    \item{\code{Y}}{verbal mean test score (y, all sixth graders)}
  }

 For convenience, the data sets \code{coleman.x}, a matrix with the 
 five (independent) variables of the data frame, and \code{coleman.y}, 
 the numeric vector giving the sixth (dependent) variable, are provided as well. 

}
\source{
 P. J. Rousseeuw and A. M. Leroy (1987) 
 \emph{Robust Regression and Outlier Detection.} Wiley, p.79, table 2. 

}
\examples{
data(coleman)
covMcd(coleman.x)
summary(lm.coleman <- lm(coleman.y ~ coleman.x))

}
\keyword{datasets}

\eof
\name{covMcd}
\alias{covMcd}
\alias{print.mcd}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Robust location and scatter estimation with high breakdown point }
\description{
     Compute a multivariate location and scale estimate with a high
     breakdown point using the Fast MCD (Minimum Covariance Determinant) Estimator.
}
\usage{
covMcd(x, cor=FALSE, alpha=1/2, nsamp=500, seed=0, print.it=FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{ a matrix or data frame. }
  \item{cor}{ should the returned result include a correlation matrix? Default is \code{cor = FALSE} }.
  \item{alpha}{ The size of the subsets over which the determinant is
minimized. Must be between the default = (n+p+1)/2 and n. Provide a fraction between .5 and 1, indicating the fraction of the data over which the determinant is minimized. }
  \item{nsamp}{ number of subsets used for initial estimates. Default is \code{nsamp = 500}}
  \item{seed}{ starting value for random generator. Default is \code{seed = 0}}
  \item{print.it}{ whether to print intermediate results. Default is \code{print.it = FALSE}}
}
\details{
  The minimum covariance determinant estimator of location and
scatter implemented in covMcd() is similar to the existing 
R function cov.mcd() in MASS. The MCD method looks for the
h(> n/2) observations (out of n) whose classical covariance 
matrix has the lowest possible determinant. The raw MCD estimate 
of location is then the average of these h points, whereas the raw MCD 
estimate of scatter is their covariance matrix, multiplied with a
consistency factor. Based on these raw MCD estimates, a reweighting step is performed
which increases the finite-sample eficiency considerably - see Pison et.al. (2002). 
The implementation in rrcov uses the Fast MCD algorithm of Rousseeuw and Van Driessen (1999) to
approximate the minimum covariance determinant estimator. 

}
\value{
  A list with components

  \item{center}{
    the final estimate of location.
  }
  \item{cov}{
    the final estimate of scatter.
  }
  \item{cor}{
    the (final) estimate of the correlation matrix (only if \code{cor = TRUE}) .
  }
  \item{crit}{
    the value of the criterion, i.e. the determinant.
  }
  \item{best}{
    the best subset found and used for computing the raw estimates. The size of \code{best} is equal to \code{quan}.
  }
  \item{mah}{
    mahalanobis distances of the observations using the final estimate of the location and scater.
  }
  \item{mcd.wt}{
    weights of the observations using the final estimate of the location and scater.
  }
  \item{raw.center}{
    the raw (not reweighted) estimate of location.
  }
  \item{raw.cov}{
    the raw (not reweighted) estimate of scatter.
  }
  \item{raw.mah}{
    mahalanobis distances of the observations based on the raw estimate of the location and scater.
  }
  \item{raw.weights}{
    weights of the observations based on the raw estimate of the location and scater.
  }
  \item{X}{
    the input data as a matrix.
  }
  \item{n.obs}{
    total number of observations. 
  }
  \item{alpha}{ 
    the size of the subsets over which the determinant is minimized (the default is (n+p+1)/2). 
  }  
  \item{quan}{ 
    the number of observations on which the MCD is based. 
    If \code{quan} equals \code{n.obs}, the MCD is the classical covariance matrix.
  }  
  \item{method}{
    character string naming the method (Minimum Covariance Determinant).
  }
  
}
\references{ 
 P. J. Rousseeuw and A. M. Leroy (1987) 
 \emph{Robust Regression and Outlier Detection.} Wiley. 
 
 P. J. Rousseeuw and K. van Driessen (1999) 
 A fast algorithm for the minimum covariance determinant estimator. 
 \emph{Technometrics} \bold{41}, 212--223.

 Pison, G., Van Aelst, S., and Willems, G. (2002), 
 Small Sample Corrections for LTS and MCD, 
 \emph{Metrika}, \bold{55}, 111-123.
 
}

% ~Make other sections like Warning with \section{Warning }{....} ~

% \seealso{}
\examples{

data(hbk)
covMcd(hbk.x)

}
\keyword{robust}
\keyword{multivariate}

\eof
\name{plot.mcd}
\alias{covPlot}
\alias{plot.mcd}
\alias{ddplot}
\alias{distplot}
\alias{chi2qqplot}
\alias{ellipse}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Robust Distance Plots }
\description{
 Shows the Mahalanobis distances based on robust and classical estimates 
of the location and the covariance matrix in different plots. 
The following plots are available:

 - index plot of the robust and mahalanobis distances
 
 - distance-distance plot
 
 - Chisquare QQ-plot of the robust and mahalanobis distances
 
 - plot of the tolerance ellipses (robust and classic)
 
}
\usage{

    ## S3 method for class 'mcd':
    plot.mcd(x, which = c("all","dd","distance","qqchi2","tolellipse"), classic=FALSE, ask=(which=="all" && dev.interactive()), cutoff, id.n, tol.inv=1e-7, ...)
    
%    covPlot(x, which = c("all","dd","distance","qqchi2","tolellipse"), classic=FALSE, ask=(which=="all" && dev.interactive()), mcd, cutoff, id.n, tol.inv = 1e-7)

ddplot(x, ...)
distplot(x, ...)
chi2qqplot(x, ...)
ellipse(x, ...)

}

%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x }{ a \code{mcd} object, typically result of \code{covMcd}. }
  \item{which}{ Which plot to show? See Details for description of the options. Default is \code{which}="all". }.
  \item{classic}{ whether to plot the classical distances too. Default is \code{classic}=FALSE. }.
  \item{ask}{ logical; if 'TRUE', the user is \emph{ask}ed before each plot, see 'par(ask=.)'. 
Default is \code{ask = which=="all" && dev.interactive()}.  }
  \item{cutoff}{ The cutoff value for the distances.  }
  \item{id.n}{ Number of observations to identify by a label. If not supplied, the number of observations with distance larger than \code{cutoff} is used.  }
  \item{tol.inv}{ tolerance to be used for computing the inverse see 'solve'. Default is \code{tol.inv = 10e-7}}
  \item{... }{ other parameters to be passed through to plotting functions. }

}
\details{

 This function produces several plots based on the robust and classical location and covariance matrix. 
Which of them to select is specified by the attribute  \code{which}.
The possible options are: 

 \code{distance} - index plot of the robust distances;
 
 \code{dd} - distance-distance plot;
 
 \code{qqchi2} - a qq-plot of the robust distances versus the quantiles of the chi-squared distribution
 
 \code{tolellipse} - a tolerance ellipse

 The Distance-Distance Plot, introduced by
Rousseeuw and van Zomeren (1990), displays the robust distances
versus the classical Mahalanobis distances. The dashed line is the set of 
points where the robust distance is equal to the classical distance.
The horizontal and vertical lines are drawn at values equal to the cutoff
which defaults to square root of the 97.5% quantile of a chi-squared 
distribution with p degrees of freedom. Points beyond these lines can 
be considered outliers.

}

}
%\value{}
\references{ 
 
     P. J. Rousseeuw and van Zomeren, B. C. (1990). Unmasking
    Multivariate Outliers and Leverage Points. \emph{Journal of the American
    Statistical Association} \bold{85}, 633-639.
    
    P. J. Rousseeuw and K. van Driessen (1999) 
    A fast algorithm for the minimum covariance determinant estimator. 
    \emph{Technometrics} \bold{41}, 212--223.
 
 }

% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
\code{\link{tolellipse}} 
}

\examples{

data(brain)
mcd <- covMcd(log(brain))
plot(mcd)
}
\keyword{robust}
\keyword{multivariate}

\eof
\name{delivery}
\alias{delivery}
\alias{delivery.x}
\alias{delivery.y}
\docType{data}
\title{ Delivery Time Data
}
\description{
   Delivery Time Data, from Montgomery and Peck (1982).
The aim is to explain the time required to service a vending 
machine (Y) by means of the number of products stocked (X1) and the 
distance walked by the route driver (X2).
}
\usage{data(delivery)}
\format{
  A data frame with 25 observations on the following 3 variables.
  \describe{
    \item{\code{X1}}{Number of Products}
    \item{\code{X2}}{Distance}
    \item{\code{Y}}{Delivery time }
  }
 For convenience, the data sets \code{delivery.x}, a matrix with 
the two (independent) variables of the data frame, and \code{delivery.y}, 
the numeric vector giving the thirth (dependent) variable, are provided as well. 
}
\source{
 P. J. Rousseeuw and A. M. Leroy (1987) 
 \emph{Robust Regression and Outlier Detection.} Wiley, page 155, table 23. 

}
\examples{
data(delivery)
covMcd(delivery.x)

summary(lm.delivery <- lm(delivery.y ~ delivery.x))

}
\keyword{datasets}

\eof
\name{hbk}
\alias{hbk}
\alias{hbk.x}
\alias{hbk.y}
\docType{data}
\title{ Hawkins, Bradu, Kass's Artificial Data }
\description{

 Artificial Data Set generated by Hawkins, Bradu, and Kass (1984). 
The data set consists of 75 observations in four dimensions 
(one response and three explanatory variables). It provides a 
good example of the masking effect. The first 14 
observations are outliers, created in two groups: 1-10 and 11-14. 
Only observations 12, 13 and 14 appear as outliers when using 
classical methods, but can be easily unmasked using robust 
distances computed by e.g. MCD - covMcd().
}
\usage{data(hbk)}
\format{
  A data frame with 75 observations on 4 variables, where the last variable is the dependent one.
%  \describe{
%    \item{X1}{x[1]}
%    \item{X2}{x[2]}
%    \item{X3}{x[3]}
%    \item{Y}{y}
%  }

 For convenience, the data sets \code{hbk.x}, a matrix with the three (independent) variables of the data frame, and \code{hbk.y}, the numeric vector giving the fourth (dependent) variable, are provided as well. 

}
\Note{
  This data set is also available in the package \code{wle} as 'artificial'
}
\source{
Hawkins, D.M., Bradu, D., and Kass, G.V. (1984)
  Location of several outliers in multiple regression data using elemental sets.
  \emph{Technometrics,}
  \bold{26}, 197--208.

}

\seealso{
 P. J. Rousseeuw and A. M. Leroy (1987) 
 \emph{Robust Regression and Outlier Detection.} Wiley, p.94. 
}
\examples{
data(hbk)
plot(hbk.x)
covMcd(hbk.x)
summary(lm.hbk <- lm(hbk.y ~ hbk.x))

}
\keyword{datasets}

\eof
\name{heart}
\alias{heart}
\alias{heart.x}
\alias{heart.y}
\docType{data}
\title{ Heart Catherization Data }
\description{
      This data set was analyzed by Weisberg (1980) and Chambers et al. (1983).
   A catheter is passed into a major vein or artery at the femoral region and moved into the heart.
The proper length of the introduced catheter has to be guessed by
the physician. The aim of the data set is to describe the relation
between the catheter length and the patient's height (X1) and
weight (X2).

 This data sets is used to demonstrate the effects caused by collinearity.
The correlation between height and weight is so high that either
variable almost completely determines the other.

}
\usage{data(heart)}
\format{
  A data frame with 12 observations on the following 3 variables.
  \describe{
    \item{\code{X1}}{Patient's height in inches}
    \item{\code{X2}}{Patient's weights in pounds}
    \item{\code{Y}}{Catheter Length (in centimeters)}
  }

 For convenience, the data sets \code{heart.x}, a matrix 
 with the first two (independent) variables of the data frame, 
 and \code{heart.y}, the numeric vector giving the thirth (dependent) 
 variable, are provided as well. 

}
%\Note{}
\source{
 P. J. Rousseeuw and A. M. Leroy (1987) 
 \emph{Robust Regression and Outlier Detection.} Wiley, p.103, table 13. 
 
}
\examples{
data(heart)
plot(heart.x)
covMcd(heart.x)
summary(lm.heart <- lm(heart.y ~ heart.x))
}
\keyword{datasets}

\eof
\name{plot.lts}
\alias{plot.lts}
\alias{ltsPlot}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Robust Regression Diagnostic Plots }
\description{
    Four plots (selectable by 'which') are currently provided: a plot
of the standardized residuals versus their index, a plot
of the standardized residuals versus fitted values, a Normal Q-Q plot of the standardized residuals, and
a regression diagnostic plot (standardized residuals versus robust distances of the predictor variables).

}
\usage{
    ## S3 method for class 'lts':
    plot.lts(x, which = c("all","rqq","rindex","rfit","rdiag"), classic=FALSE, ask=(which=="all" && dev.interactive()), id.n=3, ...)
    
%    ltsPlot(x, which = c("all","rqq","rindex","rfit","rdiag"), classic=FALSE, ask=(which=="all" && dev.interactive()), id.n=3, ...)
}

%- maybe also 'usage' for other objects documented here.
\arguments{

  \item{x }{ a \code{lts} object, typically result of \code{ltsReg}. }
  \item{which }{ Which plot to show? See Details for description of the options. Default is \code{which}="all". }.
  \item{classic }{ whether to plot the classical plots too. Default is \code{classic}=FALSE. }.
  \item{ask}{ logical; if 'TRUE', the user is \emph{ask}ed before each plot, see 'par(ask=.)'. 
Default is \code{ask = which=="all" && dev.interactive()}.  }
  \item{id.n }{ Number of observations to identify by a label starting with the most extreme. Default is \code{id.n} = 3.  }
  \item{... }{ other parameters to be passed through to plotting functions. }
  
}
\details{

 This function produces several plots based on the robust and classical regression estimates. 
Which of them to select is specified by the attribute  \code{which}.
The possible options are: 

 \code{rqq} - Normal Q-Q plot of the standardized residuals;
 
 \code{rindex} - plot of the standardized residuals versus their index;
 
 \code{rfit} - plot of the standardized residuals versus fitted values;
 
 \code{tolellipse} - regression diagnostic plot.

 The regression diagnostic Plot, introduced by
Rousseeuw and van Zomeren (1990), displays the standardized residuals versus robust distances. 
Following Rousseeuw and van Zomeren (1990), the horizontal dashed lines are located at +2.5 and -2.5 
and the vertical line is located at the upper 0.975 percent point of the chi-squared distribution 
with p degrees of freedom.

}

}
%\value{}
\references{ 
      P. J. Rousseeuw and van Zomeren, B. C. (1990). Unmasking
    Multivariate Outliers and Leverage Points. \emph{Journal of the American
    Statistical Association} \bold{85}, 633-639.
    
    P. J. Rousseeuw and K. van Driessen (1999) 
    A fast algorithm for the minimum covariance determinant estimator. 
    \emph{Technometrics} \bold{41}, 212--223.
    
 }

% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
\code{\link{covPlot}} 
}

\examples{

data(hbk)
lts <- ltsReg(hbk.x,hbk.y)
plot(lts, which="rqq")

}
\keyword{robust}
\keyword{multivariate}

\eof
\name{ltsReg}
\alias{ltsReg}
\alias{print.lts}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Robust regression with high breakdown point }
\description{
Carries out least trimmed squares (LTS) regression.
}
\usage{
ltsReg(x, y, intercept=TRUE, alpha=NULL, nsamp=500, adjust=FALSE, mcd=TRUE, qr.out=FALSE, yname=NULL, seed=0)
}
%- maybe also 'usage' for other objects documented here.
\arguments{

  \item{x}{ a matrix or data frame containing the explanatory variables. }
  \item{y}{ the response: a vector of length the number of rows of 'x'. }.
  \item{intercept}{ if true, a model with constant term will be itted; otherwise no constant term will be included. Default is \code{intercept = TRUE}  }
  \item{alpha}{ the percentage of squared residuals whose sum will be minimized. Its default value is 0.5. 
  In general, alpha must be a value between 0.5 and 1.
  }
  \item{nsamp}{ number of subsets used for initial estimates. Default is \code{nsamp = 500} }
  \item{adjust}{ whether to perform intercept adjustment at each step. This could be quite time consuming, therefore the default is \code{adjust = FALSE} }
  \item{mcd}{ whether to compute robust distances using Fast-MCD.}
  \item{qr.out}{ whether to return the QR decomposition. Default is \code{qr.out = FALSE}}
  \item{yname}{ the name of the dependent variable. Default is \code{yname = NULL}}
  \item{seed}{ starting value for random generator. Default is \code{seed = 0}}
}
\details{
 The LTS regression method minimizes the sum of the h smallest squared 
residuals, where h must be at least half the number of observations. The 
default value of h is roughly 0.5n where n is the total number of observations, 
but the user may choose any value between n/2 and n. The computations are performed 
using the Fast LTS algorithm proposed by Rousseeuw and Van Driessen (1999).
}
\value{
  An object of class '"lts"'. This is a list with components

  \item{crit}{
    the value of the objective function of the LTS regression method, i.e. the sum of the h smallest squared raw residuals.
  }
  \item{coefficients}{
    vector of coefficient estimates (including the intercept,when intercept=TRUE), obtained after reweighting
  }
  \item{best}{
    the best subset found and used for computing the raw estimates. The size of \code{best} is equal to \code{quan}.
  }
  \item{fitted.values}{
    vector like y containing the fitted values of the response after reweighting.
  }
  \item{residuals}{
    vector like y containing the residuals from the weighted least squares regression.
  }
  \item{scale}{
    scale estimate of the reweighted residuals. 
  }
  \item{rsquared}{
    robust version of R squared. 
  }
  \item{alpha}{ 
    same as the input parameter \code{alpha}.
  }  
  \item{quan}{ 
   the number h of observations that have determined the least trimmed squares estimator
  }  
  \item{intercept}{ 
    same as the input parameter \code{intercept}. 
  }  
  \item{raw.coefficients}{
    vector of raw coefficient estimates (including the intercept,when intercept=TRUE).
  }
  \item{raw.scale}{
    scale estimate of the raw residuals.
  }
  \item{raw.resid}{
    vector like y containing the raw residuals from the regression.
  }
  \item{lts.wt}{
    vector like y containing weights that can be used in a weighted
    least squares. These weights are 1 for points with reasonably
    small raw residuals, and 0 for points with large raw residuals.
  }
  \item{method}{
    character string naming the method (Least Trimmed Squares).
  }
  \item{X}{
    the input data as a matrix.
  }
  
}
\references{ 

 p. j. Rousseeuw (1984), Least Median of Squares Regression.
 \emph{Journal of the American Statistical Association}, \bold{79}, pp. 871-881. 
 
 P. J. Rousseeuw and A. M. Leroy (1987) 
 \emph{Robust Regression and Outlier Detection.} Wiley. 
 
 P. J. Rousseeuw and K. van Driessen (1999)
 Computing LTS Regression for Large Data Sets, 
 Technical Report, University of Antwerp, submitted
 
 P. J. Rousseeuw and K. van Driessen (1999) 
 A fast algorithm for the minimum covariance determinant estimator. 
 \emph{Technometrics}, \bold{41}, 212--223.

 Pison, G., Van Aelst, S., and Willems, G. (2002), 
 Small Sample Corrections for LTS and MCD, 
 \emph{Metrika}, \bold{55}, 111-123.
 
}

% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
\code{\link{covMcd}} 
}

\examples{

data(heart)
ltsReg(heart.x, heart.y)

}
\keyword{robust}

\eof
\name{milk}
\alias{milk}
\docType{data}
\title{ Daudin's Milk Composition Data
 }
\description{
 Daudin et. al. (1988) give 8 readings on the composition of 86 
 containers of milk. They speak about 85 observations, but this 
 can be explained with the fact that observations 63 and 64 are 
 identical (as noted by Rocke (1996). The data set was used for 
 analysing the stability of principal component analysis by the 
 bootstrap method. In the same context, but using high breakdown 
 point robust PCA, these data was analysed by Todorov et.al. (1994).
Atkinson (1994) used these data for ilustration of the forward 
search algorithm for identifying of multiple outliers.

 
}
\usage{data(milk)}
\format{
  A data frame with 86 observations on the following 8 variables.
  \describe{
    \item{\code{X1}}{density}
    \item{\code{X2}}{fat content, grams/liter}
    \item{\code{X3}}{protein content, grams/liter}
    \item{\code{X4}}{casein content, grams/liter}
    \item{\code{X5}}{cheese dry substance measured in the factory, grams/liter}
    \item{\code{X6}}{cheese dry substance measured in the laboratory, grams/liter}
    \item{\code{X7}}{milk dry substance, grams/liter}
    \item{\code{X8}}{cheese product, grams/liter}
  }
}
\source{
Daudin, J.J. Duby, C. and Trecourt, P. (1988) Stability of Principal
Component Analysis Studied by the Bootstrap Method \emph{Statistics}
\bold{19} 241-258.

}
\References{
Todorov, V., Neyko, N., Neytchev, P. (1994) Stability of High Breakdown
Point Robust PCA in \textit{Short Communications, COMPSTAT`94}
(Physica Verlag, Heidelberg, 1994).

Atkinson, A.C., (1994) Fast Very Robust Methods for the Detection of
Multiple Outliers. \emph{J. Amer. Statist. Assoc.} \bold{89}
1329--1339.

Rocke, D. M. and Woodruff, D. L. (1996) Identification of Outliers in
Multivariate Data, \emph{J. Amer. Statist. Assoc.} \bold{91} 435 1047--1061.

}
\examples{
data(milk)
covMcd(milk)
}
\keyword{datasets}

\eof
\name{phosphor}
\alias{phosphor}
\alias{phosphor.y}
\alias{phosphor.x} 
\docType{data}
\title{ Phosphorus Content Data }
\description{
   This dataset investigates the effect from inorganic and organic Phosphorus 
in the soil upon the phosphorus content of the corn grown in this soil, 
from Prescott (1975).

}
\usage{data(phosphor)}
\format{
  A data frame with 18 observations on the following 3 variables.
  \describe{
    \item{\code{X1}}{Inorganic Phosphorus }
    \item{\code{X2}}{Organic Phosphorus }
    \item{\code{Y}}{Plant Phosphorus }
  }
  
 For convenience, the data sets \code{phosphor.x}, a matrix with the first two (independent) variables of the data frame, and \code{phosphor.y}, the numeric vector giving the thirth (dependent) variable, are provided as well. 

}
%\Note{} 
\source{
 P. J. Rousseeuw and A. M. Leroy (1987) 
 \emph{Robust Regression and Outlier Detection.} Wiley, p.156, table 24. 
 
}

%\details{} 

\examples{
data(phosphor)
plot(phosphor.x)
covMcd(phosphor.x)
summary(lm.phosphor <- lm(phosphor.y ~ phosphor.x))
}
\keyword{datasets}

\eof
\name{salinity}
\alias{salinity}
\alias{salinity.x}
\alias{salinity.y}
\docType{data}
\title{ Salinity Data
 }
\description{
   This is a data set consisting of measurements of water salinity (i.e., its salt
concentration) and river discharge taken in North Carolina's
Pamlico Sound; This dataset was listed by Ruppert and Carroll
(1980). In Carrol and Ruppert (1985) the physical background of
the data is described. They indicated that observations 5 and 16
correspond to periods of very heavy discharge and showed that the
discrepant observation 5 was masked by observations 3 and 16 i.e.
only after deletion of these observations it was possible to
identify the influential observation 5.

 This data set is a prime example of the masking effect.

}
\usage{data(salinity)}
\format{
  A data frame with 28 observations on the following 4 variables.
  \describe{
    \item{\code{X1}}{Lagged Salinity}
    \item{\code{X2}}{Trend}
    \item{\code{X3}}{Discharge}
    \item{\code{Y}}{Salinity}
  }

For convenience, the data sets \code{salinity.x}, a matrix with the three (independent) variables of the data frame, and \code{salinity.y}, the numeric vector giving the fourth (dependent) variable, are provided as well. 
}
\source{
 P. J. Rousseeuw and A. M. Leroy (1987) 
 \emph{Robust Regression and Outlier Detection.} Wiley, p.82, table 5. 

}
\examples{
data(salinity)
covMcd(salinity.x)

summary(lm.salinity <- lm(salinity.y ~ salinity.x))

}
\keyword{datasets}

\eof
\name{stars}
\alias{stars}
\alias{stars.x}
\alias{stars.y}
\docType{data}
\title{ Data for the Hertzsprung-Russell Diagram of the star cluster CYG OB1 }
\description{
   Data for the Hertzsprung-Russell Diagram of the Star Cluster CYG OB1, 
which contains 47 stars in the direction of Czgnus, from C.Doom.
The first variable is the logarithm of the effective temperature at the surface of 
the star (Te) and the second one is the logarithm of its light intencity (L/L0).

In the Hertzsprung-Russell diagram, which is the scatterplot of these data points , 
where the log temperature is ploted from left to right, two groups of points are seen: 
the majority which tend to follow a steep band and four stars in the upper corner. 
In the astronomy the 43 stars are said to lie on the main sequence and the four 
remaining stars are called giants (the points 11, 20, 30, 34).

}
\usage{data(stars)}
\format{
  A data frame with 47 observations on the following 2 variables.
  \describe{
    \item{\code{X1}}{Logarithm of the effective temperature at the surface of the star (Te)}
    \item{\code{Y}}{Logarithm of its light intencity (L/L0)}
  }

 For convenience, the data sets \code{stars.x}, a matrix 
 with the first (independent) variable of the data frame, 
 and \code{stars.y}, the numeric vector giving the second (dependent) 
 variable, are provided as well. 

}
%\Note{}
\source{
 P. J. Rousseeuw and A. M. Leroy (1987) 
 \emph{Robust Regression and Outlier Detection.} Wiley, p.27, table 3. 
 
}
\examples{
data(stars)
plot(stars)
covMcd(stars)
lm.stars <- lm(stars.y ~ stars.x)
summary(lm.stars)
plot(lm.stars)
lts.stars<-ltsReg(stars.x, stars.y)
plot(lts.stars)

}
\keyword{datasets}

\eof
\name{tolellipse}
\alias{tolellipse}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Tolerance Ellipse Plot }
\description{
 Plots the 0.975 tolerance ellipse of the bivariate data set \code{x}.
The ellipse is defined by those data points whose distance 
is equal to the squareroot of the 0.975 chisquare quantile 
with 2 degrees of freedom. 
}
\usage{
tolellipse(x, mcd, cutoff, id.n, classic = FALSE, tol.inv=1e-7)
}

%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{ a two dimensional matrix or data frame. }
  \item{mcd}{ An object of type mcd - its attributes center and cov will be used. If missing the MCD will be computed. }
  \item{cutoff}{ Distance needed to flag data points outside the ellipse  }
  \item{id.n}{ Number of observations to identify by a label. If not supplied, the number of observations with distance larger than \code{cutoff} is used.  }
  \item{classic}{ Whether to plot the classical distances too. Default is \code{classic}=FALSE. }.
  \item{tol.inv}{ Tolerance to be used for computing the inverse see 'solve'. Default is \code{tol.inv = 10e-7}}
}

%\details{}
%\value{}
%\references{ }

% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
\code{\link{tolellipse}} 
}

\examples{

data(hbk)
mcd <- covMcd(hbk.x)       # compute mcd in advance
tolellipse(hbk.x[,1:2])    # must be a 2-dimensional data set: take the first two columns
}
\keyword{robust}
\keyword{multivariate}

\eof
\name{wood}
\alias{wood}
\alias{wood.x}
\alias{wood.y}
\docType{data}
\title{ Modified Wood Gravity Dataset }
\description{
   The original data are from Draper and Smith (1966) and
were used to determine the influence of anatomical factors on wood
specific gravity, with five explanatory variables and an
intercept. These data were contaminated by replacing a few
observations with outliers.

}
\usage{data(wood)}
\format{
  A data frame with 20 observations on the following 6 variables.
  \describe{
    \item{X1}{X1}
    \item{X2}{X2}
    \item{X3}{X3}
    \item{X4}{X4}
    \item{X5}{X5}
    \item{Y}{Y}
  }

 For convenience, the data sets \code{wood.x}, a matrix with the first 5 (independent) 
 variables of the data frame, and \code{wood.y}, the numeric vector giving the sixth 
 (dependent) variable, are provided as well. 

}
%\Note{}
\source{
 P. J. Rousseeuw and A. M. Leroy (1987) 
 \emph{Robust Regression and Outlier Detection.} Wiley, p.243, table 8. 
 
}
\examples{
data(wood)
plot(wood.x)
covMcd(wood.x)
summary(lm.wood <- lm(wood.y ~ wood.x))
}
\keyword{datasets}

\eof
